.. _index:

#####
tmuxp
#####
====================
tmux session manager
====================

.. include:: ../README.rst
    :start-line: 2
    :end-before: .. image

.. image:: _static/tmuxp-demo.gif
    :width: 100%

Freeze a tmux session
---------------------
.. include:: ../README.rst
    :start-after: ---------------------

Table of Contents
-----------------
.. toctree::
    :maxdepth: 2

    about
    quickstart
    examples
    cli
    developing
    api
    history
    about_tmux
    glossary
